apply_sig_stars: Apply significance stars to a melliotab object

View source: R/significance-stars.R

apply_sig_starsR Documentation

Apply significance stars to a melliotab object

Description

Adds significance stars to the target column based on p-values, and optionally removes the p-value column.

Usage

apply_sig_stars(
  mt,
  target = "auto",
  remove_p = TRUE,
  levels = c(`*` = 0.05, `**` = 0.01, `***` = 0.001)
)

Arguments

mt

A melliotab object

target

Column index or name to add stars to ("auto" to detect)

remove_p

Whether to remove the p-value column

levels

Named character vector of significance levels

Value

Modified melliotab object


mellio documentation built on Aug. 30, 2026, 1:06 a.m.