format_business_number: Format a number with thousands separators and parenthetical...

View source: R/format-numbers.R

format_business_numberR Documentation

Format a number with thousands separators and parenthetical negatives

Description

Format a number with thousands separators and parenthetical negatives

Usage

format_business_number(value, use_parenthetical = TRUE)

Arguments

value

Character string containing the number

use_parenthetical

Whether to use parentheses for negatives

Value

Formatted character string


mellio documentation built on Aug. 30, 2026, 1:06 a.m.