is_stat_symbol: Check if a header is a statistical symbol that should be...

View source: R/detect-columns.R

is_stat_symbolR Documentation

Check if a header is a statistical symbol that should be italicized

Description

Check if a header is a statistical symbol that should be italicized

Usage

is_stat_symbol(header)

Arguments

header

Column header string

Value

Logical


mellio documentation built on Aug. 30, 2026, 1:06 a.m.