mt_copy: Copy a melliotab table to the system clipboard

View source: R/copy.R

mt_copyR Documentation

Copy a melliotab table to the system clipboard

Description

Copies the formatted table to the clipboard as rich HTML so it can be pasted into Word with formatting preserved.

Usage

mt_copy(x)

Arguments

x

A melliotab object

Value

Invisible melliotab object (for piping)

Examples


if (interactive()) {
  model <- lm(mpg ~ wt + hp, data = mtcars)
  tab <- melliotab(model, title = "Regression Results")
  mt_copy(tab)
  # Now paste into Word
}


mellio documentation built on Aug. 30, 2026, 1:06 a.m.