View source: R/significance-stars.R
| apply_sig_stars | R Documentation |
Adds significance stars to the target column based on p-values, and optionally removes the p-value column.
apply_sig_stars(
mt,
target = "auto",
remove_p = TRUE,
levels = c(`*` = 0.05, `**` = 0.01, `***` = 0.001)
)
mt |
A melliotab object |
target |
Column index or name to add stars to ("auto" to detect) |
remove_p |
Whether to remove the p-value column |
levels |
Named character vector of significance levels |
Modified melliotab object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.