| mt_copy | R Documentation |
Copies the formatted table to the clipboard as rich HTML so it can be pasted into Word with formatting preserved.
mt_copy(x)
x |
A melliotab object |
Invisible melliotab object (for piping)
if (interactive()) {
model <- lm(mpg ~ wt + hp, data = mtcars)
tab <- melliotab(model, title = "Regression Results")
mt_copy(tab)
# Now paste into Word
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.